class JsonUtil(object):
    pass
    # def getAppJson(self, name):
    #     """ generated source for method getAppJson """
    #     result1 = ""
    #     try:
    #         result1 = fileinput.input()
    #         # result1 = IOUtils(
    #         #     FileInputStream(File(System.getProperty("user.dir") + "/src/test/resources/" + name + ".json")))
    #     except Exception as e:
    #         print(e)
    #     result = JSONObject()
    #     return result
