class OptimusCloudConfiguration(object):
    AKIRA_HOST = "http://localhost:6889"
    MDB_HOST = "http://localhost:9909"
    MATCH_MAKER_HOST = "http://localhost:6898"
    RABBIT_MQ_HOST = "http://localhost:15672"
